==========================
Command line documentation
==========================

.. mdinclude:: ../../README.md
   :start-line: 102
   :end-line: 424

..
   note: start- and end-line are 0-indexed.
   options: https://docutils.sourceforge.io/docs/ref/rst/directives.html#include
